@@ -32,11 +32,13 @@
 
 #include "actions/actiondef.h"
 
-#include "being/attributes.h"
 #include "being/localplayer.h"
 #include "being/playerinfo.h"
 
-#include "gui/dialogtype.h"
+#include "enums/being/attributes.h"
+
+#include "enums/gui/dialogtype.h"
+
 #include "gui/gui.h"
 #include "gui/popupmanager.h"
 #include "gui/sdlinput.h"
@@ -1516,4 +1518,11 @@ impHandler(kick)
     return true;
 }
 
+impHandler0(clearDrop)
+{
+    if (dropShortcut)
+        dropShortcut->clear();
+    return true;
+}
+
 }  // namespace Actions
