@@ -26,10 +26,11 @@
 #include "resources/map/mapconsts.h"
 
 #include "being/actor.h"
-#include "being/actortype.h"
 #include "being/compoundsprite.h"
-#include "being/targetcursorsize.h"
-#include "being/targetcursortype.h"
+
+#include "enums/being/actortype.h"
+#include "enums/being/targetcursorsize.h"
+#include "enums/being/targetcursortype.h"
 
 #include "particle/particlelist.h"
 #include "particle/particlevector.h"
