@@ -36,11 +36,14 @@
 #include "statuseffect.h"
 #include "resources/map/walklayer.h"
 
-#include "being/attributes.h"
 #include "being/beingflag.h"
 #include "being/playerinfo.h"
 #include "being/playerrelations.h"
 
+#include "enums/being/attributes.h"
+
+#include "enums/net/packettypes.h"
+
 #include "particle/particle.h"
 
 #include "input/keyboardconfig.h"
@@ -54,6 +57,7 @@
 #include "gui/windows/outfitwindow.h"
 #include "gui/windows/shopwindow.h"
 #include "gui/windows/socialwindow.h"
+#include "gui/windows/statuswindow.h"
 #include "gui/windows/updaterwindow.h"
 
 #include "gui/widgets/tabs/chat/gmtab.h"
@@ -398,6 +402,8 @@ void LocalPlayer::setGMLevel(const int level)
     if (level > 0)
     {
         setGM(true);
+        if (statusWindow)
+            statusWindow->updateLevelLabel();
         if (chatWindow)
         {
             chatWindow->loadGMCommands();
