@@ -23,8 +23,9 @@
 #define BEING_PLAYERINFO_H
 
 #include "equipment.h"
-#include "guildpositionflags.h"
-#include "state.h"
+
+#include "enums/guildpositionflags.h"
+#include "enums/state.h"
 
 #include <map>
 
