@@ -245,7 +245,7 @@ static void createGuiWindows()
         const std::string lang = getLangShort();
         if (lang.size() == 2)
         {
-            langChatTab = new LangTab(chatWindow, lang);
+            langChatTab = new LangTab(chatWindow, lang + " ");
             langChatTab->setAllowHighlight(false);
         }
     }
@@ -256,14 +256,9 @@ static void createGuiWindows()
     debugChatTab->setAllowHighlight(false);
 
     if (config.getBoolValue("enableTradeTab"))
-    {
-        tradeChatTab = new TradeTab(chatWindow);
-        tradeChatTab->setAllowHighlight(false);
-    }
+        chatWindow->addSpecialChannelTab(TRADE_CHANNEL, false);
     else
-    {
         tradeChatTab = nullptr;
-    }
 
     if (config.getBoolValue("enableBattleTab"))
     {
@@ -278,7 +273,7 @@ static void createGuiWindows()
     if (localPlayer && !gmChatTab && config.getBoolValue("enableGmTab")
         && localPlayer->getGMLevel() > 0)
     {
-        gmChatTab = new GmTab(chatWindow);
+        chatWindow->addSpecialChannelTab(GM_CHANNEL, false);
     }
 
     if (!isSafeMode && chatWindow)
