@@ -26,7 +26,8 @@
 
 #include "being/localplayer.h"
 
-#include "gui/dialogtype.h"
+#include "enums/gui/dialogtype.h"
+
 #include "gui/viewport.h"
 
 #include "gui/windows/chatwindow.h"
