@@ -24,7 +24,6 @@
 
 #include "actormanager.h"
 #include "configuration.h"
-#include "dropshortcut.h"
 #include "gamemodifiers.h"
 #include "guild.h"
 #include "guildmanager.h"
@@ -1018,11 +1017,6 @@ void PopupMenu::handleLink(const std::string &link,
         mDialog->setActionEventId("ok");
         mDialog->addActionListener(&mRenameListener);
     }
-    else if (link == "clear drops")
-    {
-        if (dropShortcut)
-            dropShortcut->clear();
-    }
     else if (link == "edit spell" && mSpell)
     {
         (new TextCommandEditor(mSpell))->postInit();
@@ -1862,7 +1856,7 @@ void PopupMenu::showDropPopup(const int x, const int y, Item *const item)
     }
     mBrowserBox->addRow("##3---");
     // TRANSLATORS: popup menu item
-    mBrowserBox->addRow("clear drops", _("Clear drop window"));
+    mBrowserBox->addRow("/cleardrops", _("Clear drop window"));
     mBrowserBox->addRow("##3---");
     // TRANSLATORS: popup menu item
     // TRANSLATORS: close menu
@@ -2352,7 +2346,7 @@ void PopupMenu::addFollow()
     }
     // TRANSLATORS: popup menu item
     // TRANSLATORS: imitate player
-    mBrowserBox->addRow("/imitation 'NAME'", _("Imitation"));
+    mBrowserBox->addRow("/imitation 'NAME'", _("Imitate"));
 }
 
 void PopupMenu::addBuySell(const Being *const being)
