@@ -2,7 +2,7 @@
  *  The ManaPlus Client
  *  Copyright (C) 2004-2009  The Mana World Development Team
  *  Copyright (C) 2009-2010  The Mana Developers
- *  Copyright (C) 2011-2014  The ManaPlus Developers
+ *  Copyright (C) 2011-2015  The ManaPlus Developers
  *  Copyright (C) 2009  Aethyra Development Team
  *
  *  This file is part of The ManaPlus Client.
@@ -223,7 +223,7 @@ void BrowserBox::addRow(const std::string &row, const bool atTop)
                 if (idx2 == std::string::npos)
                     break;
 
-                const std::string str = inputManager.getKeyValueByName(
+                const std::string str = inputManager.getKeyValueByNameLong(
                     tmp.substr(idx1 + 3, idx2 - idx1 - 3));
                 tmp.replace(idx1, idx2 - idx1 + 1, str);
 
