@@ -2,7 +2,7 @@
  *  The ManaPlus Client
  *  Copyright (C) 2004-2009  The Mana World Development Team
  *  Copyright (C) 2009-2010  The Mana Developers
- *  Copyright (C) 2011-2014  The ManaPlus Developers
+ *  Copyright (C) 2011-2015  The ManaPlus Developers
  *
  *  This file is part of The ManaPlus Client.
  *
@@ -552,7 +552,8 @@ void ItemContainer::mouseReleased(MouseEvent &event)
             const Item *const item = inventory->getItem(dragDrop.getTag());
             if (item && !PlayerInfo::isItemProtected(item->getId()))
             {
-                mInventory->addItem(item->getId(), 1, 1, item->getColor(),
+                mInventory->addItem(item->getId(), item->getType(),
+                    1, 1, item->getColor(),
                     item->getIdentified(), item->getDamaged(),
                     item->getFavorite(),
                     false, false);
