@@ -30,11 +30,12 @@
 #include "settings.h"
 #include "spellshortcut.h"
 
-#include "being/attributes.h"
 #include "being/localplayer.h"
 #include "being/playerinfo.h"
 #include "being/playerrelations.h"
 
+#include "enums/being/attributes.h"
+
 #include "input/inputmanager.h"
 
 #include "gui/chatconsts.h"
@@ -60,6 +61,7 @@
 
 #include "gui/widgets/tabs/chat/battletab.h"
 #include "gui/widgets/tabs/chat/channeltab.h"
+#include "gui/widgets/tabs/chat/gmtab.h"
 #include "gui/widgets/tabs/chat/langtab.h"
 #include "gui/widgets/tabs/chat/tradetab.h"
 #include "gui/widgets/tabs/chat/whispertab.h"
@@ -373,6 +375,24 @@ void ChatWindow::nextTab()
     mChatTabs->setSelectedTabByIndex(tab);
 }
 
+void ChatWindow::selectTabByType(const ChatTabType::Type &type)
+{
+    if (!mChatTabs)
+        return;
+
+    int sz = mChatTabs->getNumberOfTabs();
+    for (int f = 0; f < sz; f ++)
+    {
+        ChatTab *const tab = dynamic_cast<ChatTab*>(
+            mChatTabs->getTabByIndex(f));
+        if (tab && tab->getType() == type)
+        {
+            mChatTabs->setSelectedTab(tab);
+            break;
+        }
+    }
+}
+
 void ChatWindow::closeTab() const
 {
     if (!mChatTabs)
@@ -1175,12 +1195,41 @@ WhisperTab *ChatWindow::getWhisperTab(const std::string &nick) const
     return ret;
 }
 
-ChannelTab *ChatWindow::addChannelTab(const std::string &name,
-                                      const bool switchTo)
+ChatTab *ChatWindow::addSpecialChannelTab(const std::string &name,
+                                          const bool switchTo)
+{
+    ChatTab *ret = nullptr;
+    if (name == TRADE_CHANNEL)
+    {
+        if (!tradeChatTab)
+        {
+            tradeChatTab = new TradeTab(chatWindow);
+            tradeChatTab->setAllowHighlight(false);
+        }
+        ret = tradeChatTab;
+    }
+    else if (name == GM_CHANNEL)
+    {
+        if (!gmChatTab)
+            gmChatTab = new GmTab(chatWindow);
+        ret = gmChatTab;
+    }
+    if (switchTo)
+        mChatTabs->setSelectedTab(ret);
+
+    return ret;
+}
+
+ChatTab *ChatWindow::addChannelTab(const std::string &name,
+                                   const bool switchTo)
 {
     std::string tempName = name;
     toLower(tempName);
 
+    ChatTab *const tab = addSpecialChannelTab(name, switchTo);
+    if (tab)
+        return tab;
+
     const ChannelMap::const_iterator i = mChannels.find(tempName);
     ChannelTab *ret = nullptr;
 
@@ -1637,7 +1686,7 @@ void ChatWindow::channelChatLog(const std::string &channel,
     std::string tempChannel = channel;
     toLower(tempChannel);
 
-    ChannelTab *tab = nullptr;
+    ChatTab *tab = nullptr;
     const ChannelMap::const_iterator i = mChannels.find(tempChannel);
 
     if (i != mChannels.end())
