@@ -32,10 +32,11 @@
 #include "client.h"
 #include "game.h"
 
-#include "being/attributes.h"
 #include "being/localplayer.h"
 #include "being/playerinfo.h"
 
+#include "enums/being/attributes.h"
+
 #include "resources/map/map.h"
 
 #include "utils/gettext.h"
