@@ -27,11 +27,12 @@
 #include "item.h"
 #include "units.h"
 
-#include "being/attributes.h"
 #include "being/localplayer.h"
 #include "being/playerinfo.h"
 #include "being/playerrelations.h"
 
+#include "enums/being/attributes.h"
+
 #include "gui/gui.h"
 
 #include "gui/fonts/font.h"
