@@ -26,6 +26,8 @@
 #include "configuration.h"
 #include "settings.h"
 
+#include "enums/net/updatetype.h"
+
 #include "input/inputaction.h"
 
 #include "gui/widgets/browserbox.h"
@@ -38,7 +40,6 @@
 #include "gui/widgets/scrollarea.h"
 
 #include "net/download.h"
-#include "net/updatetype.h"
 
 #include "resources/resourcemanager.h"
 
@@ -1044,7 +1045,8 @@ bool UpdaterWindow::validateFile(const std::string &filePath,
 unsigned long UpdaterWindow::getFileHash(const std::string &filePath)
 {
     int size = 0;
-    const char *const buf = static_cast<const char*>(PhysFs::loadFile(filePath, size));
+    const char *const buf = static_cast<const char*>(
+        PhysFs::loadFile(filePath, size));
     if (!buf)
         return 0;
     return Net::Download::adlerBuffer(buf, size);
