@@ -526,6 +526,15 @@ namespace InputAction
         PET_DIRECT_RIGHT,
         PET_AI_START,
         PET_AI_STOP,
+        CHAT_GENERAL_TAB,
+        CHAT_DEBUG_TAB,
+        CHAT_BATTLE_TAB,
+        CHAT_TRADE_TAB,
+        CHAT_LANG_TAB,
+        CHAT_GM_TAB,
+        CHAT_PARTY_TAB,
+        CHAT_GUILD_TAB,
+        DROP_CLEAR,
         TOTAL
     };
 }  // namespace InputAction
