@@ -235,6 +235,12 @@ SetupActionData setupActionDataWindows[] =
         InputAction::NEXT_INV_TAB,
         "",
     },
+    {
+        // TRANSLATORS: input action name
+        N_("Clear drops window"),
+        InputAction::DROP_CLEAR,
+        "",
+    },
     {
         "",
         InputAction::NO_VALUE,
