@@ -56,14 +56,17 @@ class CharServerHandler notfinal
 
         virtual void chooseCharacter(Net::Character *const character) = 0;
 
-        virtual void newCharacter(const std::string &name, const int slot,
-                                  const bool gender, const int hairstyle,
+        virtual void newCharacter(const std::string &name,
+                                  const int slot,
+                                  const Gender::Type gender,
+                                  const int hairstyle,
                                   const int hairColor,
                                   const unsigned char race,
                                   const unsigned char look,
                                   const std::vector<int> &stats) const = 0;
 
-        virtual void deleteCharacter(Net::Character *const character) = 0;
+        virtual void deleteCharacter(Net::Character *const character,
+                                     const std::string &email) = 0;
 
         virtual void renameCharacter(const int id,
                                      const std::string &newName) = 0;
