@@ -112,6 +112,7 @@ BeingHandler::BeingHandler(const bool enableSync) :
         SMSG_BEING_STAT_UPDATE_1,
         SMSG_MOB_INFO,
         SMSG_BEING_MOVE3,
+        SMSG_BEING_ATTRS,
         0
     };
     handledMessages = _messages;
@@ -301,6 +302,10 @@ void BeingHandler::handleMessage(Net::MessageIn &msg)
             processBeingMove3(msg);
             break;
 
+        case SMSG_BEING_ATTRS:
+            processBeingAttrs(msg);
+            break;
+
         default:
             break;
     }
@@ -409,7 +414,8 @@ void BeingHandler::processBeingChangeLookContinue(Being *const dstBeing,
     switch (type)
     {
         case 0:  // change race
-            dstBeing->setSubtype(static_cast<uint16_t>(id), 0);
+            dstBeing->setSubtype(static_cast<uint16_t>(id),
+                dstBeing->getLook());
             break;
         case 1:  // eAthena LOOK_HAIR
             dstBeing->setSpriteID(SPRITE_HAIR_COLOR, id *-1);
@@ -441,8 +447,8 @@ void BeingHandler::processBeingChangeLookContinue(Being *const dstBeing,
                 ItemDB::get(dstBeing->getSpriteID(
                 SPRITE_HAIR_COLOR)).getDyeColorsString(id));
             break;
-        case 7:  // Clothes color
-            // ignoring it
+        case 7:  // Clothes color. Now used as look
+            dstBeing->setLook(static_cast<uint8_t>(id));
             break;
         case 8:  // eAthena LOOK_SHIELD
             if (!mHideShield)
@@ -1111,15 +1117,15 @@ void BeingHandler::processBeingAction2(Net::MessageIn &msg)
 
     switch (type)
     {
-        case Being::HIT:  // Damage
-        case Being::CRITICAL:  // Critical Damage
-        case Being::MULTI:  // Critical Damage
-        case Being::MULTI_REFLECT:
-        case Being::REFLECT:  // Reflected Damage
-        case Being::FLEE:  // Lucky Dodge
-        case Being::SPLASH:
-        case Being::SKILL:
-        case Being::REPEATE:
+        case AttackType::HIT:  // Damage
+        case AttackType::CRITICAL:  // Critical Damage
+        case AttackType::MULTI:  // Critical Damage
+        case AttackType::MULTI_REFLECT:
+        case AttackType::REFLECT:  // Reflected Damage
+        case AttackType::FLEE:  // Lucky Dodge
+        case AttackType::SPLASH:
+        case AttackType::SKILL:
+        case AttackType::REPEATE:
             if (srcBeing)
             {
                 if (srcSpeed && srcBeing->getType() == ActorType::Player)
@@ -1132,17 +1138,17 @@ void BeingHandler::processBeingAction2(Net::MessageIn &msg)
             if (dstBeing)
             {
                 dstBeing->takeDamage(srcBeing, param1,
-                    static_cast<Being::AttackType>(type));
+                    static_cast<AttackType::Type>(type));
             }
             break;
 
-        case Being::PICKUP:
+        case AttackType::PICKUP:
             break;
 
-        case Being::TOUCH_SKILL:
+        case AttackType::TOUCH_SKILL:
             break;
 
-        case Being::SIT:
+        case AttackType::SIT:
             if (srcBeing)
             {
                 srcBeing->setAction(BeingAction::SIT, 0);
@@ -1155,7 +1161,7 @@ void BeingHandler::processBeingAction2(Net::MessageIn &msg)
             }
             break;
 
-        case Being::STAND:
+        case AttackType::STAND:
             if (srcBeing)
             {
                 srcBeing->setAction(BeingAction::STAND, 0);
@@ -1546,4 +1552,26 @@ void BeingHandler::processMobInfo(Net::MessageIn &msg)
         dstBeing->setAttackRange(attackRange);
 }
 
+void BeingHandler::processBeingAttrs(Net::MessageIn &msg)
+{
+    const int len = msg.readInt16("len");
+    if (len < 12)
+        return;
+    Being *const dstBeing = actorManager->findBeing(
+        msg.readInt32("player id"));
+    const int gmLevel = msg.readInt32("gm level");
+    if (dstBeing && gmLevel)
+    {
+        if (dstBeing == localPlayer)
+            localPlayer->setGMLevel(gmLevel);
+        dstBeing->setGM(true);
+    }
+    else
+    {
+        if (dstBeing == localPlayer)
+            localPlayer->setGMLevel(0);
+        dstBeing->setGM(false);
+    }
+}
+
 }  // namespace EAthena
