@@ -26,9 +26,9 @@
 #include "configuration.h"
 #include "settings.h"
 
-#include "being/attributes.h"
+#include "enums/being/attributes.h"
 
-#include "gui/dialogtype.h"
+#include "enums/gui/dialogtype.h"
 
 #include "gui/windows/charcreatedialog.h"
 #include "gui/windows/charselectdialog.h"
@@ -36,6 +36,7 @@
 
 #include "net/character.h"
 #include "net/logindata.h"
+#include "net/serverfeatures.h"
 
 #include "net/eathena/gamehandler.h"
 #include "net/eathena/loginhandler.h"
@@ -199,7 +200,8 @@ void CharServerHandler::readPlayerData(Net::MessageIn &msg,
     data.mAttributes[Attributes::MAX_MP] = msg.readInt16("max mp/sp");
 
     msg.readInt16("speed");
-    tempPlayer->setSubtype(msg.readInt16("class"), 0);
+    const uint16_t race = msg.readInt16("class");
+//    tempPlayer->setSubtype(race, 0);
     const int hairStyle = msg.readInt16("hair style");
     const int weapon = msg.readInt32("weapon");
 
@@ -217,7 +219,8 @@ void CharServerHandler::readPlayerData(Net::MessageIn &msg,
         ItemDB::get(-hairStyle).getDyeColorsString(
         msg.readInt16("hair color")));
 
-    const int misc2 = msg.readInt16("clothes color");
+    const uint8_t look = msg.readInt16("clothes color");
+    tempPlayer->setSubtype(race, look);
     tempPlayer->setName(msg.readString(24, "name"));
 
     character->dummy = tempPlayer;
@@ -244,7 +247,7 @@ void CharServerHandler::readPlayerData(Net::MessageIn &msg,
 
     tempPlayer->setSprite(SPRITE_CLOTHES_COLOR, hat);
     tempPlayer->setSprite(SPRITE_HEAD_BOTTOM, topClothes);
-    tempPlayer->setSprite(SPRITE_HEAD_MID, misc2);
+//    tempPlayer->setSprite(SPRITE_HEAD_MID, misc2);
     msg.readInt32("slot change");
     tempPlayer->setRename(msg.readInt32("rename (inverse)"));
 
@@ -267,10 +270,10 @@ void CharServerHandler::chooseCharacter(Net::Character *const character)
 }
 
 void CharServerHandler::newCharacter(const std::string &name, const int slot,
-                                     const bool gender A_UNUSED,
+                                     const Gender::Type gender,
                                      const int hairstyle, const int hairColor,
-                                     const unsigned char race A_UNUSED,
-                                     const unsigned char look A_UNUSED,
+                                     const unsigned char race,
+                                     const unsigned char look,
                                      const std::vector<int> &stats A_UNUSED)
                                      const
 {
@@ -280,9 +283,23 @@ void CharServerHandler::newCharacter(const std::string &name, const int slot,
     outMsg.writeInt8(static_cast<unsigned char>(slot), "slot");
     outMsg.writeInt16(static_cast<int16_t>(hairColor), "hair color");
     outMsg.writeInt16(static_cast<int16_t>(hairstyle), "hair style");
+    if (serverFeatures->haveRaceSelection())
+        outMsg.writeInt16(static_cast<int16_t>(race), "race");
+    if (serverFeatures->haveCreateCharGender())
+    {
+        uint8_t sex = 0;
+        if (gender == Gender::UNSPECIFIED)
+            sex = 99;
+        else
+            sex = Being::genderToInt(gender);
+        outMsg.writeInt8(sex, "gender");
+    }
+    if (serverFeatures->haveLookSelection())
+        outMsg.writeInt16(static_cast<int16_t>(look), "look");
 }
 
-void CharServerHandler::deleteCharacter(Net::Character *const character)
+void CharServerHandler::deleteCharacter(Net::Character *const character,
+                                        const std::string &email)
 {
     if (!character)
         return;
@@ -291,7 +308,10 @@ void CharServerHandler::deleteCharacter(Net::Character *const character)
 
     createOutPacket(CMSG_CHAR_DELETE);
     outMsg.writeInt32(mSelectedCharacter->dummy->getId(), "id?");
-    outMsg.writeString("a@a.com", 40, "email");
+    if (email.empty())
+        outMsg.writeString("a@a.com", 40, "email");
+    else
+        outMsg.writeString(email, 40, "email");
 }
 
 void CharServerHandler::switchCharacter() const
@@ -334,7 +354,7 @@ void CharServerHandler::setCharCreateDialog(CharCreateDialog *const window)
     const Token &token = static_cast<LoginHandler*>(loginHandler)->getToken();
 
     mCharCreateDialog->setAttributes(attributes, 0, 0, 0);
-    mCharCreateDialog->setFixedGender(true, token.sex);
+    mCharCreateDialog->setDefaultGender(token.sex);
 }
 
 void CharServerHandler::processCharLogin(Net::MessageIn &msg)
@@ -590,4 +610,18 @@ void CharServerHandler::processCharChangeSlot(Net::MessageIn &msg)
     msg.readInt16("unused");
 }
 
+void CharServerHandler::processCharDeleteFailed(Net::MessageIn &msg)
+{
+    BLOCK_START("CharServerHandler::processCharDeleteFailed")
+    unlockCharSelectDialog();
+    msg.readUInt8("error");
+    // TRANSLATORS: error message
+    new OkDialog(_("Error"), _("Failed to delete character."),
+        // TRANSLATORS: ok dialog button
+        _("OK"),
+        DialogType::ERROR,
+        true, true, nullptr, 260);
+    BLOCK_END("CharServerHandler::processCharDeleteFailed")
+}
+
 }  // namespace EAthena
