@@ -45,16 +45,20 @@ class CharServerHandler final : public MessageHandler,
 
         void chooseCharacter(Net::Character *const character) override final;
 
-        void newCharacter(const std::string &name, const int slot,
-                          const bool gender, const int hairstyle,
-                          const int hairColor, const unsigned char race,
+        void newCharacter(const std::string &name,
+                          const int slot,
+                          const Gender::Type gender,
+                          const int hairstyle,
+                          const int hairColor,
+                          const unsigned char race,
                           const unsigned char look,
                           const std::vector<int> &stats) const override final;
 
         void renameCharacter(const int id,
                              const std::string &newName) override final;
 
-        void deleteCharacter(Net::Character *const character) override final;
+        void deleteCharacter(Net::Character *const character,
+                             const std::string &email) override final;
 
         void switchCharacter() const override final;
 
@@ -98,6 +102,8 @@ class CharServerHandler final : public MessageHandler,
 
         static void processCharChangeSlot(Net::MessageIn &msg);
 
+        static void processCharDeleteFailed(Net::MessageIn &msg);
+
     private:
         static std::string mNewName;
         static uint32_t mPinSeed;
