@@ -127,6 +127,7 @@
 #define SMSG_BEING_CHANGE_DIRECTION  0x009c
 #define SMSG_BEING_RESURRECT         0x0148
 #define SMSG_BEING_STAT_UPDATE_1     0x01ab
+#define SMSG_BEING_ATTRS             0x0b0a
 
 #define SMSG_PLAYER_STATUS_CHANGE    0x0229
 #define SMSG_PLAYER_STATUS_CHANGE2   0x028a
@@ -301,6 +302,18 @@
 #define SMSG_FRIENDS_REQUEST_ACK     0x0209
 
 #define SMSG_AUCTION_OPEN_WINDOW     0x025f
+#define SMSG_AUCTION_RESULTS         0x0252
+#define SMSG_AUCTION_SET_ITEM        0x0256
+#define SMSG_AUCTION_MESSAGE         0x0250
+#define SMSG_AUCTION_CLOSE           0x025d
+
+#define SMSG_VENDING_OPEN_REQ        0x012d
+#define SMSG_VENDING_SHOW_BOARD      0x0131
+#define SMSG_VENDING_HIDE_BOARD      0x0132
+#define SMSG_VENDING_ITEMS_LIST      0x0800
+#define SMSG_VENDING_BUY_ACK         0x0135
+#define SMSG_VENDING_OPEN            0x0136
+#define SMSG_VENDING_REPORT          0x0137
 
 #define SMSG_ELEMENTAL_UPDATE_STATUS 0x081e
 #define SMSG_ELEMENTAL_INFO          0x081d
@@ -512,4 +525,19 @@
 #define CMSG_FRIENDS_REQUEST_ACK     0x0208
 #define CMSG_FRIENDS_DELETE_PLAYER   0x020a
 
+#define CMSG_AUCTION_CANCEL_REG      0x024b
+#define CMSG_AUCTION_SET_ITEM        0x024c
+#define CMSG_AUCTION_REGISTER        0x024d
+#define CMSG_AUCTION_CANCEL          0x024e
+#define CMSG_AUCTION_CLOSE           0x025d
+#define CMSG_AUCTION_BID             0x024f
+#define CMSG_AUCTION_SEARCH          0x0251
+#define CMSG_AUCTION_BUY_SELL        0x025c
+
+#define CMSG_VENDING_CLOSE           0x012e
+#define CMSG_VENDING_LIST_REQ        0x0130
+#define CMSG_VENDING_BUY             0x0134
+#define CMSG_VENDING_BUY2            0x0801
+#define CMSG_VENDING_CREATE_SHOP     0x01b2
+
 #endif  // NET_EATHENA_PROTOCOL_H
