@@ -76,6 +76,8 @@ class ServerFeatures final : public Net::ServerFeatures
 
         bool haveEmailOnRegister() const override final;
 
+        bool haveEmailOnDelete() const override final;
+
         bool haveEightDirections() const override final;
 
         bool haveCharRename() const override final;
@@ -91,6 +93,8 @@ class ServerFeatures final : public Net::ServerFeatures
         bool haveJoinChannel() const override final;
 
         bool haveNpcWhispers() const override final;
+
+        bool haveCreateCharGender() const override final;
 };
 
 }  // namespace EAthena
