@@ -73,6 +73,8 @@ class ServerFeatures notfinal
 
         virtual bool haveEmailOnRegister() const = 0;
 
+        virtual bool haveEmailOnDelete() const = 0;
+
         virtual bool haveEightDirections() const = 0;
 
         virtual bool haveCharRename() const = 0;
@@ -88,6 +90,8 @@ class ServerFeatures notfinal
         virtual bool haveJoinChannel() const = 0;
 
         virtual bool haveNpcWhispers() const = 0;
+
+        virtual bool haveCreateCharGender() const = 0;
 };
 
 }  // namespace Net
