@@ -24,9 +24,10 @@
 
 #include "notifymanager.h"
 
-#include "being/attributes.h"
 #include "being/playerinfo.h"
 
+#include "enums/being/attributes.h"
+
 #include "gui/windows/buydialog.h"
 
 #include "net/serverfeatures.h"
