@@ -26,9 +26,12 @@
 #include "configuration.h"
 #include "settings.h"
 
-#include "being/attributes.h"
+#include "enums/being/attributes.h"
+
+#include "enums/gui/dialogtype.h"
 
 #include "gui/windows/charcreatedialog.h"
+#include "gui/windows/okdialog.h"
 
 #include "net/character.h"
 #include "net/logindata.h"
@@ -265,7 +268,7 @@ void CharServerHandler::chooseCharacter(Net::Character *const character)
 }
 
 void CharServerHandler::newCharacter(const std::string &name, const int slot,
-                                     const bool gender A_UNUSED,
+                                     const Gender::Type gender A_UNUSED,
                                      const int hairstyle,
                                      const int hairColor,
                                      const unsigned char race,
@@ -289,7 +292,8 @@ void CharServerHandler::newCharacter(const std::string &name, const int slot,
         outMsg.writeInt8(race, "class");
 }
 
-void CharServerHandler::deleteCharacter(Net::Character *const character)
+void CharServerHandler::deleteCharacter(Net::Character *const character,
+                                        const std::string &email A_UNUSED)
 {
     if (!character)
         return;
@@ -373,7 +377,7 @@ void CharServerHandler::setCharCreateDialog(CharCreateDialog *const window)
         sumStat = 30;
 
     mCharCreateDialog->setAttributes(attributes, sumStat, minStat, maxStat);
-    mCharCreateDialog->setFixedGender(true, token.sex);
+    mCharCreateDialog->setDefaultGender(token.sex);
 }
 
 void CharServerHandler::processCharLogin(Net::MessageIn &msg)
@@ -521,4 +525,18 @@ void CharServerHandler::changeSlot(const int oldSlot A_UNUSED,
 {
 }
 
+void CharServerHandler::processCharDeleteFailed(Net::MessageIn &msg)
+{
+    BLOCK_START("CharServerHandler::processCharDeleteFailed")
+    unlockCharSelectDialog();
+    msg.readUInt8("error");
+    // TRANSLATORS: error message
+    new OkDialog(_("Error"), _("Failed to delete character."),
+        // TRANSLATORS: ok dialog button
+        _("OK"),
+        DialogType::ERROR,
+        true, true, nullptr, 260);
+    BLOCK_END("CharServerHandler::processCharDeleteFailed")
+}
+
 }  // namespace TmwAthena
