@@ -45,13 +45,17 @@ class CharServerHandler final : public MessageHandler,
 
         void chooseCharacter(Net::Character *const character) override final;
 
-        void newCharacter(const std::string &name, const int slot,
-                          const bool gender, const int hairstyle,
-                          const int hairColor, const unsigned char race,
+        void newCharacter(const std::string &name,
+                          const int slot,
+                          const Gender::Type gender,
+                          const int hairstyle,
+                          const int hairColor,
+                          const unsigned char race,
                           const unsigned char look,
                           const std::vector<int> &stats) const override final;
 
-        void deleteCharacter(Net::Character *const character) override final;
+        void deleteCharacter(Net::Character *const character,
+                             const std::string &email) override final;
 
         void renameCharacter(const int id,
                              const std::string &newName) override final;
@@ -90,6 +94,8 @@ class CharServerHandler final : public MessageHandler,
         static void processCharCreate(Net::MessageIn &msg);
 
         static void processCharCreate2(Net::MessageIn &msg);
+
+        static void processCharDeleteFailed(Net::MessageIn &msg);
 };
 
 }  // namespace TmwAthena
