@@ -134,6 +134,11 @@ bool ServerFeatures::haveEmailOnRegister() const
     return serverVersion >= 7;
 }
 
+bool ServerFeatures::haveEmailOnDelete() const
+{
+    return false;
+}
+
 bool ServerFeatures::haveEightDirections() const
 {
     return false;
@@ -179,4 +184,9 @@ bool ServerFeatures::haveNpcWhispers() const
     return false;
 }
 
+bool ServerFeatures::haveCreateCharGender() const
+{
+    return false;
+}
+
 }  // namespace TmwAthena
