@@ -38,6 +38,8 @@ namespace
     unsigned mSumStat = 0;
     unsigned mMinLook = 0;
     unsigned mMaxLook = 0;
+    unsigned mMinRace = 0;
+    unsigned mMaxRace = 30;
     std::vector<int> mDefaultItems;
 }  // namespace
 
@@ -83,6 +85,10 @@ void CharDB::load()
             if (id > 0)
                 mDefaultItems.push_back(id);
         }
+        else if (xmlNameEqual(node, "race"))
+        {
+            loadMinMax(node, &mMinRace, &mMaxRace);
+        }
     }
 
     delete doc;
@@ -150,6 +156,16 @@ unsigned CharDB::getMaxLook()
     return mMaxLook;
 }
 
+unsigned CharDB::getMinRace()
+{
+    return mMinRace;
+}
+
+unsigned CharDB::getMaxRace()
+{
+    return mMaxRace;
+}
+
 const std::vector<int> &CharDB::getDefaultItems()
 {
     return mDefaultItems;
